@@ -2,11 +2,12 @@
 Package `profile-translator-blocklist`.
 """
 
-from .translator import translate_policy, translate_policies, translate_profile
+from .translator import slugify_name, translate_policy, translate_policies, translate_profile
 from .Policy import Policy
 
 
 __all__ = [
+    "slugify_name",
     "translate_policy",
     "translate_policies",
     "translate_profile",
